==> mobile_pos-1.1.1.tar.gz: lib/src/shared_widgets/business_type_sheet.dart <==
import 'package:flutter/material.dart';
import 'package:mobile_pos/src/helpers/const.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_textfeild.dart';
import 'package:mobile_pos/src/shared_widgets/string_list_tile.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';

class BusinessTypeSheet extends StatefulWidget {
  const BusinessTypeSheet({Key? key}) : super(key: key);

  @override
  BusinessTypeSheetState createState() => BusinessTypeSheetState();
}

class BusinessTypeSheetState extends State<BusinessTypeSheet> {
  List<String> searchedBusiness = [];
  List<String> businessFromStore = [];
  String searchString = '';

  void searchPlace(String businessName) async {
    if (businessName.isNotEmpty) {
      searchedBusiness.clear();
      for (var element in businessFromStore) {
        if (element.toLowerCase().contains(businessName.toLowerCase())) {
          searchedBusiness.add(element);
        }
      }

      setState(() {
        searchedBusiness = searchedBusiness;
      });
    }
  }

  @override
  void initState() {
    super.initState();
    setState(() {
      businessFromStore = businessSectors.toList();
    });
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: MediaQuery.of(context).size.height * .92,
      child: Stack(
        children: [
          Container(
            color: pluginTheme.getFGColor,
            height: double.infinity,
          ),
          Container(
              width: double.infinity,
              height: 55.0,
              color: pluginTheme.isLightTheme ? const Color(0xFFF1F3F6) : null,
              child: Padding(
                padding: const EdgeInsets.all(16.0),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    Text(
                      'Select Business Type',
                      style: subtitle.copyWith(
                          fontSize: 18,
                          color: pluginTheme.primaryColor,
                          fontWeight: FontWeight.w700),
                    ),
                    // IconButton(
                    //     padding: const EdgeInsets.only(bottom: 6),
                    //     onPressed: () {
                    //       Navigator.pop(context);
                    //     },
                    //     icon: ),
                    InkWell(
                      onTap: () {
                        Navigator.pop(context);
                      },
                      child: Icon(
                        Icons.close,
                        color: pluginTheme.primaryColor,
                      ),
                    )
                  ],
                ),
              )),
          Padding(
            padding:
                const EdgeInsets.only(top: 40, left: 16, right: 16, bottom: 10),
            child: RavenPayTextField(
              contentPadding:
                  const EdgeInsets.symmetric(horizontal: 16, vertical: 16),
              hintText: 'Search Business',
              onChanged: (value) {
                setState(() {
                  searchString = value;
                  searchPlace(searchString);
                });
              },
            ),
          ),
          Padding(
            padding: const EdgeInsets.only(top: 120.0),
            child: SingleChildScrollView(
              child: Padding(
                padding:
                    const EdgeInsets.symmetric(horizontal: 16, vertical: 12),
                child: ListView.separated(
                  padding: const EdgeInsets.all(0),
                  itemBuilder: (context, index) {
                    return StringListTile(
                      title: (searchString.isNotEmpty)
                          ? searchedBusiness[index]
                          : businessFromStore[index],
                    );
                  },
                  separatorBuilder: (BuildContext context, int index) =>
                      const SizedBox(
                    height: 4,
                  ),
                  itemCount: (searchString.isNotEmpty)
                      ? searchedBusiness.length
                      : businessFromStore.length,
                  shrinkWrap: true,
                  physics: const ClampingScrollPhysics(),
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }
}

==> mobile_pos-2.0.0.tar.gz: lib/src/shared_widgets/business_type_sheet.dart <==
import 'package:flutter/material.dart';
import 'package:mobile_pos/src/helpers/const.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_textfeild.dart';
import 'package:mobile_pos/src/shared_widgets/string_list_tile.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';

class BusinessTypeSheet extends StatefulWidget {
  const BusinessTypeSheet({super.key});

  @override
  BusinessTypeSheetState createState() => BusinessTypeSheetState();
}

class BusinessTypeSheetState extends State<BusinessTypeSheet> {
  List<String> searchedBusiness = [];
  List<String> businessFromStore = [];
  String searchString = '';

  void searchPlace(String businessName) async {
    if (businessName.isNotEmpty) {
      searchedBusiness.clear();
      for (var element in businessFromStore) {
        if (element.toLowerCase().contains(businessName.toLowerCase())) {
          searchedBusiness.add(element);
        }
      }

      setState(() {
        searchedBusiness = searchedBusiness;
      });
    }
  }

  @override
  void initState() {
    super.initState();
    setState(() {
      businessFromStore = businessSectors.toList();
    });
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: MediaQuery.of(context).size.height * .92,
      child: Stack(
        children: [
          Container(
            color: pluginTheme.getFGColor,
            height: double.infinity,
          ),
          Container(
              width: double.infinity,
              height: 55.0,
              color: pluginTheme.isLightTheme ? const Color(0xFFF1F3F6) : null,
              child: Padding(
                padding: const EdgeInsets.all(16.0),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    Text(
                      'Select Business Type',
                      style: subtitle.copyWith(
                          fontSize: 18,
                          color: pluginTheme.primaryColor,
                          fontWeight: FontWeight.w700),
                    ),
                    // IconButton(
                    //     padding: const EdgeInsets.only(bottom: 6),
                    //     onPressed: () {
                    //       Navigator.pop(context);
                    //     },
                    //     icon: ),
                    InkWell(
                      onTap: () {
                        Navigator.pop(context);
                      },
                      child: Icon(
                        Icons.close,
                        color: pluginTheme.primaryColor,
                      ),
                    )
                  ],
                ),
              )),
          Padding(
            padding:
                const EdgeInsets.only(top: 40, left: 16, right: 16, bottom: 10),
            child: RavenPayTextField(
              contentPadding:
                  const EdgeInsets.symmetric(horizontal: 16, vertical: 16),
              hintText: 'Search Business',
              onChanged: (value) {
                setState(() {
                  searchString = value;
                  searchPlace(searchString);
                });
              },
            ),
          ),
          Padding(
            padding: const EdgeInsets.only(top: 120.0),
            child: SingleChildScrollView(
              child: Padding(
                padding:
                    const EdgeInsets.symmetric(horizontal: 16, vertical: 12),
                child: ListView.separated(
                  padding: const EdgeInsets.all(0),
                  itemBuilder: (context, index) {
                    return StringListTile(
                      title: (searchString.isNotEmpty)
                          ? searchedBusiness[index]
                          : businessFromStore[index],
                    );
                  },
                  separatorBuilder: (BuildContext context, int index) =>
                      const SizedBox(
                    height: 4,
                  ),
                  itemCount: (searchString.isNotEmpty)
                      ? searchedBusiness.length
                      : businessFromStore.length,
                  shrinkWrap: true,
                  physics: const ClampingScrollPhysics(),
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }
}
